# WellKnownIssuerInfo

A collection of well known information about the issuer that is available to any authenticated user that is apart of the organisation the issuer is associated with. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**issuer_id** | **str** | Unique identifier | [optional] [readonly] 
**supported_mfa_methods** | **list[str]** | A list of supported MFA methods. An empty list implies that no MFA methods are acceptable | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


